@@ -1,8 +1,7 @@
 # Copyright (c) 2008-2015 MetPy Developers.
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
-r"""This module contains a variety of meteorological calculations.
-"""
+r"""This module contains a variety of meteorological calculations."""
 
 from .basic import *  # noqa: F403
 from .kinematics import *  # noqa: F403
@@ -10,8 +9,7 @@ from .thermo import *  # noqa: F403
 from .tools import *  # noqa: F403
 from . import turbulence  # noqa: F401
 
-__all__ = []
-__all__.extend(basic.__all__)  # pylint: disable=undefined-variable
+__all__ = basic.__all__[:]  # pylint: disable=undefined-variable
 __all__.extend(kinematics.__all__)  # pylint: disable=undefined-variable
 __all__.extend(thermo.__all__)  # pylint: disable=undefined-variable
 __all__.extend(tools.__all__)  # pylint: disable=undefined-variable
