@@ -1,21 +1,29 @@
 # Copyright (c) 2008-2015 MetPy Developers.
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
+"""Contains a collection of basic calculations.
+
+These include:
+
+* wind components
+* heat index
+* windchill
+"""
 
 from __future__ import division
-import numpy as np
-from numpy.ma import masked_array
-from ..constants import g, Rd, omega
-from ..package_tools import Exporter
-from ..units import atleast_1d, units
 
+import numpy as np
+
+from ..constants import g, omega, Rd
+from ..package_tools import Exporter
+from ..units import atleast_1d, masked_array, units
 
 exporter = Exporter(globals())
 
 
 @exporter.export
 def get_wind_speed(u, v):
-    r'''Compute the wind speed from u and v-components.
+    r"""Compute the wind speed from u and v-components.
 
     Parameters
     ----------
@@ -32,14 +40,14 @@ def get_wind_speed(u, v):
     See Also
     --------
     get_wind_components
-    '''
+    """
     speed = np.sqrt(u * u + v * v)
     return speed
 
 
 @exporter.export
 def get_wind_dir(u, v):
-    r'''Compute the wind direction from u and v-components.
+    r"""Compute the wind direction from u and v-components.
 
     Parameters
     ----------
@@ -50,14 +58,14 @@ def get_wind_dir(u, v):
 
     Returns
     -------
-    wind direction: array_like
-        The direction of the wind in degrees, specified as the direction from
-        which it is blowing
+    wind direction: `pint.Quantity`
+        The direction of the wind, specified as the direction from
+        which it is blowing, with 0 being North.
 
     See Also
     --------
     get_wind_components
-    '''
+    """
     wdir = 90. * units.deg - np.arctan2(-v, -u)
     origshape = wdir.shape
     wdir = atleast_1d(wdir)
@@ -67,8 +75,7 @@ def get_wind_dir(u, v):
 
 @exporter.export
 def get_wind_components(speed, wdir):
-    r'''Calculate the U, V wind vector components from the speed and
-    direction.
+    r"""Calculate the U, V wind vector components from the speed and direction.
 
     Parameters
     ----------
@@ -76,7 +83,7 @@ def get_wind_components(speed, wdir):
         The wind speed (magnitude)
     wdir : array_like
         The wind direction, specified as the direction from which the wind is
-        blowing.
+        blowing, with 0 being North.
 
     Returns
     -------
@@ -86,7 +93,8 @@ def get_wind_components(speed, wdir):
 
     See Also
     --------
-    get_speed_dir
+    get_wind_speed
+    get_wind_dir
 
     Examples
     --------
@@ -94,8 +102,7 @@ def get_wind_components(speed, wdir):
     >>> metpy.calc.get_wind_components(10. * units('m/s'), 225. * units.deg)
     (<Quantity(7.071067811865475, 'meter / second')>,
      <Quantity(7.071067811865477, 'meter / second')>)
-    '''
-
+    """
     u = -speed * np.sin(wdir)
     v = -speed * np.cos(wdir)
     return u, v
@@ -103,39 +110,38 @@ def get_wind_components(speed, wdir):
 
 @exporter.export
 def windchill(temperature, speed, face_level_winds=False, mask_undefined=True):
-    r'''Calculate the Wind Chill Temperature Index (WCTI) from the current
-    temperature and wind speed.
+    r"""Calculate the Wind Chill Temperature Index (WCTI).
+
+    Calculates WCTI from the current temperature and wind speed using the formula
+    outlined by the FCM [4]_.
 
     Specifically, these formulas assume that wind speed is measured at
     10m.  If, instead, the speeds are measured at face level, the winds
     need to be multiplied by a factor of 1.5 (this can be done by specifying
-    `face_level_winds` as True.)
+    `face_level_winds` as `True`.)
 
     Parameters
     ----------
-    temperature : array_like
+    temperature : `pint.Quantity`
         The air temperature
-    speed : array_like
+    speed : `pint.Quantity`
         The wind speed at 10m.  If instead the winds are at face level,
-        `face_level_winds` should be set to True and the 1.5 multiplicative
+        `face_level_winds` should be set to `True` and the 1.5 multiplicative
         correction will be applied automatically.
-
-    Returns
-    -------
-    array_like
-        The corresponding Wind Chill Temperature Index value(s)
-
-    Other Parameters
-    ----------------
     face_level_winds : bool, optional
         A flag indicating whether the wind speeds were measured at facial
         level instead of 10m, thus requiring a correction.  Defaults to
-        False.
+        `False`.
     mask_undefined : bool, optional
         A flag indicating whether a masked array should be returned with
         values where wind chill is undefined masked.  These are values where
         the temperature > 50F or wind speed <= 3 miles per hour. Defaults
-        to True.
+        to `True`.
+
+    Returns
+    -------
+    `pint.Quantity`
+        The corresponding Wind Chill Temperature Index value(s)
 
     See Also
     --------
@@ -143,11 +149,16 @@ def windchill(temperature, speed, face_level_winds=False, mask_undefined=True):
 
     References
     ----------
-    .. [4] http://www.ofcm.gov/jagti/r19-ti-plan/pdf/03_chap3.pdf
-    '''
-
+    .. [4] Federal Coordinator for Meteorological Services and Supporting Research: Report on
+           Wind Chill Temperature and Extreme Heat Indices: Evaluation and Improvement
+           Projects. Washington, DC: Office of the Federal Coordinator for Meteorological
+           Services and Supporting Research, 2003.
+           `FCM-R19-2003 <../_static/FCM-R19-2003-WindchillReport.pdf>`_
+    """
     # Correct for lower height measurement of winds if necessary
     if face_level_winds:
+        # No in-place so that we copy
+        # noinspection PyAugmentAssignment
         speed = speed * 1.5
 
     temp_limit, speed_limit = 10. * units.degC, 3 * units.mph
@@ -167,14 +178,14 @@ def windchill(temperature, speed, face_level_winds=False, mask_undefined=True):
 
 @exporter.export
 def heat_index(temperature, rh, mask_undefined=True):
-    r'''Calculate the Heat Index from the current temperature and relative
-    humidity.
+    r"""Calculate the Heat Index from the current temperature and relative humidity.
 
-    The implementation uses the formula outlined in [6].
+    The implementation uses the formula outlined in [6]_. This equation is a multi-variable
+    least-squares regression of the values obtained in [5]_.
 
     Parameters
     ----------
-    temperature : array_like
+    temperature : `pint.Quantity`
         Air temperature
     rh : array_like
         The relative humidity expressed as a unitless ratio in the range [0, 1].
@@ -182,7 +193,7 @@ def heat_index(temperature, rh, mask_undefined=True):
 
     Returns
     -------
-    array_like
+    `pint.Quantity`
         The corresponding Heat Index value(s)
 
     Other Parameters
@@ -191,7 +202,7 @@ def heat_index(temperature, rh, mask_undefined=True):
         A flag indicating whether a masked array should be returned with
         values where heat index is undefined masked.  These are values where
         the temperature < 80F or relative humidity < 40 percent. Defaults
-        to True.
+        to `True`.
 
     See Also
     --------
@@ -203,10 +214,10 @@ def heat_index(temperature, rh, mask_undefined=True):
            temperature-humidity index based on human physiology and clothing
            science. J. Appl. Meteor., 18, 861-873.
 
-    .. [6] http://www.srh.noaa.gov/ffc/html/studies/ta_htindx.PDF
-
-    '''
-
+    .. [6] Rothfusz, L.P.: The Heat Index "Equation". Fort Worth, TX: Scientific Services
+           Division, NWS Southern Region Headquarters, 1990.
+           `SR90-23 <http://www.weather.gov/media/ffc/ta_htindx.PDF>`_
+    """
     delta = temperature - 0. * units.degF
     rh2 = rh * rh
     delta2 = delta * delta
@@ -222,25 +233,25 @@ def heat_index(temperature, rh, mask_undefined=True):
     if mask_undefined:
         mask = np.array((temperature < 80. * units.degF) | (rh < 40 * units.percent))
         if mask.any():
-            hi = units.Quantity(masked_array(hi, mask=mask), hi.units)
+            hi = masked_array(hi, mask=mask)
 
     return hi
 
 
 @exporter.export
 def pressure_to_height_std(pressure):
-    r'''Convert pressure data to heights using the U.S. standard atmosphere.
+    r"""Convert pressure data to heights using the U.S. standard atmosphere.
 
-    The implementation uses the formula outlined in [7].
+    The implementation uses the formula outlined in [7]_.
 
     Parameters
     ----------
-    pressure : array_like
+    pressure : `pint.Quantity`
         Atmospheric pressure
 
     Returns
     -------
-    array_like
+    `pint.Quantity`
         The corresponding height value(s)
 
     Notes
@@ -251,7 +262,7 @@ def pressure_to_height_std(pressure):
     ----------
     .. [7] Hobbs, Peter V. and Wallace, John M., 1977: Atmospheric Science, an Introductory
             Survey. 60-61.
-    '''
+    """
     t0 = 288. * units.kelvin
     gamma = 6.5 * units('K/km')
     p0 = 1013.25 * units.mbar
@@ -260,9 +271,9 @@ def pressure_to_height_std(pressure):
 
 @exporter.export
 def coriolis_parameter(latitude):
-    r'''Calculate the coriolis parameter at each point.
+    r"""Calculate the coriolis parameter at each point.
 
-    The implementation uses the formula outlined in [8].
+    The implementation uses the formula outlined in [8]_.
 
     Parameters
     ----------
@@ -271,12 +282,12 @@ def coriolis_parameter(latitude):
 
     Returns
     -------
-    array_like
+    `pint.Quantity`
         The corresponding coriolis force at each point
 
     References
     ----------
     .. [8] Hobbs, Peter V. and Wallace, John M., 1977: Atmospheric Science, an Introductory
             Survey. 370-371.
-    '''
+    """
     return 2. * omega * np.sin(latitude)
