@@ -1,6 +1,7 @@
-# Copyright (c) 2008-2015 MetPy Developers.
+# Copyright (c) 2008-2016 MetPy Developers.
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
+"""Calculations and tools for triangles."""
 
 from __future__ import division
 
@@ -12,7 +13,7 @@ from scipy.spatial import cKDTree
 
 
 def triangle_area(pt1, pt2, pt3):
-    r"""Returns the area of a triangle.
+    r"""Return the area of a triangle.
 
     Parameters
     ----------
@@ -28,7 +29,6 @@ def triangle_area(pt1, pt2, pt3):
     area: float
         Area of the given triangle.
     """
-
     a = 0.0
 
     a += pt1[0] * pt2[1] - pt2[0] * pt1[1]
@@ -39,7 +39,7 @@ def triangle_area(pt1, pt2, pt3):
 
 
 def dist_2(x0, y0, x1, y1):
-    r"""Returns the squared distance between two points.
+    r"""Return the squared distance between two points.
 
     This is faster than calculating distance but should
     only be used with comparable ratios.
@@ -64,14 +64,13 @@ def dist_2(x0, y0, x1, y1):
     --------
     distance
     """
-
     d0 = x1 - x0
     d1 = y1 - y0
     return d0 * d0 + d1 * d1
 
 
 def distance(p0, p1):
-    r"""Returns the distance between two points.
+    r"""Return the distance between two points.
 
     Parameters
     ----------
@@ -89,16 +88,13 @@ def distance(p0, p1):
     --------
     dist_2
     """
-
     return math.sqrt(dist_2(p0[0], p0[1], p1[0], p1[1]))
 
 
 def circumcircle_radius_2(pt0, pt1, pt2):
-    r"""Calculates and returns the squared radius of a
-    given triangle's circumcircle.
+    r"""Calculate and return the squared radius of a given triangle's circumcircle.
 
-    This is faster than calculating radius but should
-    only be used with comparable ratios.
+    This is faster than calculating radius but should only be used with comparable ratios.
 
     Parameters
     ----------
@@ -118,7 +114,6 @@ def circumcircle_radius_2(pt0, pt1, pt2):
     --------
     circumcenter
     """
-
     a = distance(pt0, pt1)
     b = distance(pt1, pt2)
     c = distance(pt2, pt0)
@@ -135,8 +130,7 @@ def circumcircle_radius_2(pt0, pt1, pt2):
 
 
 def circumcircle_radius(pt0, pt1, pt2):
-    r"""Calculates and returns the radius of a given
-    triangle's circumcircle.
+    r"""Calculate and return the radius of a given triangle's circumcircle.
 
     Parameters
     ----------
@@ -156,7 +150,6 @@ def circumcircle_radius(pt0, pt1, pt2):
     --------
     circumcenter
     """
-
     a = distance(pt0, pt1)
     b = distance(pt1, pt2)
     c = distance(pt2, pt0)
@@ -172,10 +165,9 @@ def circumcircle_radius(pt0, pt1, pt2):
 
 
 def circumcenter(pt0, pt1, pt2):
-    r"""Calculates and returns the circumcenter of
-    a circumcircle generated by a given triangle.
-    All three points must be unique or a division
-    by zero error will be raised.
+    r"""Calculate and return the circumcenter of a circumcircle generated by a given triangle.
+
+    All three points must be unique or a division by zero error will be raised.
 
     Parameters
     ----------
@@ -195,7 +187,6 @@ def circumcenter(pt0, pt1, pt2):
     --------
     circumcenter
     """
-
     a_x = pt0[0]
     a_y = pt0[1]
     b_x = pt1[0]
@@ -228,13 +219,11 @@ def circumcenter(pt0, pt1, pt2):
 
 
 def find_natural_neighbors(tri, grid_points):
-    r"""Returns the natural neighbor triangles for
-    each given grid cell determined by the proper-
-    ties of the given delaunay triangulation.
+    r"""Return the natural neighbor triangles for each given grid cell.
 
-    A triangle is a natural neighbor of a grid cell
-    if that triangles circumcenter is within the
-    circumradius of the grid cell center.
+    These are determined by the properties of the given delaunay triangulation.
+    A triangle is a natural neighbor of a grid cell if that triangles circumcenter
+    is within the circumradius of the grid cell center.
 
     Parameters
     ----------
@@ -252,14 +241,13 @@ def find_natural_neighbors(tri, grid_points):
         Circumcenter and radius information for each
         triangle in 'tri'.
     """
-
     tree = cKDTree(grid_points)
 
     in_triangulation = tri.find_simplex(tree.data) >= 0
 
     triangle_info = dict()
 
-    members = dict((key, []) for key in range(len(tree.data)))
+    members = {key: [] for key in range(len(tree.data))}
 
     for i, simplices in enumerate(tri.simplices):
 
@@ -280,9 +268,10 @@ def find_natural_neighbors(tri, grid_points):
 
 
 def find_nn_triangles_point(tri, cur_tri, point):
-    r"""Returns the natural neighbors of a triangle
-    containing a point based on the provided
-    Delaunay Triangulation.
+    r"""Return the natural neighbors of a triangle containing a point.
+
+    This is based on the provided Delaunay Triangulation.
+
     Parameters
     ----------
     tri: Object
@@ -299,7 +288,6 @@ def find_nn_triangles_point(tri, cur_tri, point):
         List of simplex codes for natural neighbor
         triangles in 'tri'.
     """
-
     nn = []
 
     candidates = set(tri.neighbors[cur_tri])
@@ -324,9 +312,9 @@ def find_nn_triangles_point(tri, cur_tri, point):
 
 
 def find_local_boundary(tri, triangles):
-    r"""Finds and returns the outside edges of a collection
-    of natural neighbor triangles.  There is no guarantee
-    that this boundary is convex, so ConvexHull is not
+    r"""Find and return the outside edges of a collection of natural neighbor triangles.
+
+    There is no guarantee that this boundary is convex, so ConvexHull is not
     sufficient in some situations.
 
     Parameters
@@ -342,7 +330,6 @@ def find_local_boundary(tri, triangles):
         List of vertex codes that form outer edges of
         a group of natural neighbor triangles.
     """
-
     edges = []
 
     for triangle in triangles:
