@@ -8,6 +8,5 @@ from . import _mpl  # noqa: F401
 from .skewt import *  # noqa: F403
 from .station_plot import *  # noqa: F403
 
-__all__ = []
-__all__.extend(skewt.__all__)  # pylint: disable=undefined-variable
+__all__ = skewt.__all__[:]  # pylint: disable=undefined-variable
 __all__.extend(station_plot.__all__)  # pylint: disable=undefined-variable
