@@ -1,7 +1,7 @@
-# Copyright (c) 2008-2015 MetPy Developers.
+# Copyright (c) 2008-2016 MetPy Developers.
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
-r'''Module to provide unit support.
+r"""Module to provide unit support.
 
 This makes use of the :mod:`pint` library and sets up the default settings
 for good temperature support.
@@ -11,9 +11,10 @@ Attributes
 units : :class:`pint.UnitRegistry`
     The unit registry used throughout the package. Any use of units in MetPy should
     import this registry and use it to grab units.
-'''
+"""
 
 from __future__ import division
+
 import numpy as np
 import pint
 import pint.unit
@@ -29,7 +30,7 @@ units.define(pint.unit.UnitDefinition('percent', '%', (),
 
 
 def concatenate(arrs, axis=0):
-    r'''Concatenate multiple values into a new unitized object.
+    r"""Concatenate multiple values into a new unitized object.
 
     This is essentially a unit-aware version of `numpy.concatenate`. All items
     must be able to be converted to the same units. If an item has no units, it will be given
@@ -48,8 +49,7 @@ def concatenate(arrs, axis=0):
     -------
     `pint.Quantity`
         New container with the value passed in and units corresponding to the first item.
-    '''
-
+    """
     dest = 'dimensionless'
     for a in arrs:
         if hasattr(a, 'units'):
@@ -66,7 +66,7 @@ def concatenate(arrs, axis=0):
 
 
 def atleast_1d(*arrs):
-    r'''Convert inputs to arrays with at least one dimension
+    r"""Convert inputs to arrays with at least one dimension.
 
     Scalars are converted to 1-dimensional arrays, whilst other
     higher-dimensional inputs are preserved. This is a thin wrapper
@@ -81,8 +81,7 @@ def atleast_1d(*arrs):
     -------
     `pint.Quantity`
         A single quantity or a list of quantities, matching the number of inputs.
-    '''
-
+    """
     mags = [a.magnitude for a in arrs]
     orig_units = [a.units for a in arrs]
     ret = np.atleast_1d(*mags)
@@ -92,7 +91,7 @@ def atleast_1d(*arrs):
 
 
 def atleast_2d(*arrs):
-    r'''Convert inputs to arrays with at least two dimensions
+    r"""Convert inputs to arrays with at least two dimensions.
 
     Scalars and 1-dimensional arrays are converted to 2-dimensional arrays,
     whilst other higher-dimensional inputs are preserved. This is a thin wrapper
@@ -107,8 +106,7 @@ def atleast_2d(*arrs):
     -------
     `pint.Quantity`
         A single quantity or a list of quantities, matching the number of inputs.
-    '''
-
+    """
     mags = [a.magnitude for a in arrs]
     orig_units = [a.units for a in arrs]
     ret = np.atleast_2d(*mags)
@@ -117,4 +115,30 @@ def atleast_2d(*arrs):
     return [units.Quantity(m, u) for m, u in zip(ret, orig_units)]
 
 
+def masked_array(data, data_units=None, **kwargs):
+    """Create a :class:`numpy.ma.MaskedArray` with units attached.
+
+    This is a thin wrapper around :func:`numpy.ma.masked_array` that ensures that
+    units are properly attached to the result (otherwise units are silently lost). Units
+    are taken from the ``units`` argument, or if this is ``None``, the units on ``data``
+    are used.
+
+    Parameters
+    ----------
+    data : array_like
+        The source data. If ``units`` is `None`, this should be a `pint.Quantity` with
+        the desired units.
+    data_units : str or `pint.Unit`
+        The units for the resulting `pint.Quantity`
+    **kwargs : Arbitrary keyword arguments passed to `numpy.ma.masked_array`
+
+    Returns
+    -------
+    `pint.Quantity`
+    """
+    if data_units is None:
+        data_units = data.units
+    return units.Quantity(np.ma.masked_array(data, **kwargs), data_units)
+
+
 del pint
